/**
 * Copyright 2010 Northrop Grumman Corporation
 * All Rights Reserved
 *
 * This material may be reproduced by or for the U.S. Government pursuant to the
 * copyright license under the clause at Defense Federal Acquisition Regulation
 * Supplement (DFARS) 252.227-7014 (June 1995).
 */
package com.northgrum.jacob.common.demo;

import java.util.Map;

import javax.jws.WebParam;
import javax.jws.WebService;

import com.northgrum.jacob.common.JacobService;

/**
 * The Interface JacobDemoService.
 */
@WebService
public interface JacobDemoService extends JacobService
{

	/**
	 * Echo. A simple demo call that returns "Service says xxx" where xxx is
	 * what you passed in. Server-side implementation also demonstrates how to 
	 * get the authenticated user name for the call.
	 * 
	 * The @WebParam annotation is necessary as java interfaces do not store the
	 * Parameter name in the .class file. So if you leave out the annotation
	 * your parameter will be named arg0.
	 * 
	 * @param text
	 *            the text to echo back
	 * 
	 * @return the string
	 */
	String echo(@WebParam(name = "text") String text);

	/**
	 * Adds the object to demo map.
	 * 
	 * @param o
	 *            the object to add
	 * 
	 * @return a message about the current state of the map
	 */
	String addObjectToDemoMap(@WebParam(name = "o") Object o);

	/**
	 * Map passing: JAXB also does not support Maps. It handles Lists great, but
	 * Maps are not supported directly. Aegis does.
	 * 
	 * @return a map of count-to-object, populated by addObjectToDemoMap()
	 */
	Map<Integer, Object> getDemoMap();
 }
